@@ -1,9 +1,8 @@
 #! /usr/bin/perl -w
 
-# Copyright (c) 2003-2014 Henk Penning, all rights reserved.
-# penning@uu.nl, http://www.staff.science.uu.nl/~penni101/
+# Copyright (c) 2003-2012 Henk Penning, all rights reserved.
+# penning@cs.uu.nl, http://www.cs.uu.nl/staff/henkp.html
 # Version 1.1 was donated to the Apache Software Foundation 2003 Jan 28.
-#
 # Permission is hereby granted, free of charge, to any person obtaining a
 # copy of this software and associated documentation files (the "Software"),
 # to deal in the Software without restriction, including without limitation
@@ -29,16 +28,16 @@
 use strict ;
 
 our $PRG = 'mirmon' ;
-our $VER = "2.10" ;
+our $VER = "2.5" ;
 
 our $DEF_TIMEOUT = 300 ;
 our $HIST        = 14 ;
 our $TIM_PAT     = '^(\d+)([smhd])$' ;
 our %APA_TYPES   = () ; $APA_TYPES { $_ } ++ for qw(backup ftp http rsync) ;
-our %GET_OPTS    = () ; $GET_OPTS  { $_ } ++ for qw(all update url) ;
+our %GET_OPTS    = () ; $GET_OPTS  { $_ } ++ for qw(all update) ;
 our $HIST_DELTA  = 24 * 60 * 60 ;
 our $APRX_DELTA  = 300 ;
-our $HOME        = 'http://www.staff.science.uu.nl/~penni101/mirmon/' ;
+our $HOME        = 'http://www.cs.uu.nl/people/henkp/mirmon/' ;
 
 package Base ; #####################################################
 
@@ -212,7 +211,7 @@ sub find_config
   { my $self = shift ;
     my $arg = shift ;
     my @LIST = $arg ? ( $arg ) : Mirmon -> config_list ;
-    for my $conf ( @LIST ) { return $conf if -r $conf and ! -d $conf ; }
+    for my $conf ( @LIST ) { return $conf if -f $conf ; }
     die sprintf "can't find a config file :\n  %s\n" , join "\n  ", @LIST ;
   }
 
@@ -319,22 +318,6 @@ sub get_regions
     close REGS ;
   }
 
-sub _cmp_ccs
-  { my $ccs = shift ;
-    my $x  = shift ;
-    my $y  = shift ;
-    my $xx = $ccs -> { $x } ;
-    my $yy = $ccs -> { $y } ;
-    if ( ! defined $xx and ! defined $yy )
-      { $x cmp $y ; }
-    elsif ( ! defined $xx )
-      { -1 ; }
-    elsif ( ! defined $yy )
-      { +1 ; }
-    else
-      { $xx cmp $yy ; }
-  }
-
 sub _pr_round
   { my $x = shift ;
     my $i = int $x ;
@@ -418,7 +401,6 @@ sub _randomize
 sub get_dates
   { my $self  = shift ;
     my $get   = shift ;
-    my $URL   = shift ;
     my $state = $self -> state ;
     my $conf  = $self -> conf ;
     my $CMD   = $conf -> probe ;
@@ -427,7 +409,7 @@ sub get_dates
     my @QUE   = () ;
     my $GET   = IO::Select -> new () ;
     my $ques  = {} ;
-    for my $col ( qw(new red grn xtr) )
+    for my $col ( qw(grn red new) )
       { $ques -> { $col } { $_ } = [] for qw(done todo) ; }
     my $max_poll = s4tim $conf -> max_poll ;
     my $min_poll = s4tim $conf -> min_poll ;
@@ -436,8 +418,6 @@ sub get_dates
 
     if ( $get eq 'all' )
       { @QUE = sort { $a -> url cmp $b -> url } values %$state ; }
-    elsif ( $get eq 'url' )
-      { @QUE = ( $state -> { $URL } ) ; }
     elsif ( $get eq 'update' )
       { my $maxp = $^T - $max_poll ;
         my $minp = $^T - $min_poll ;
@@ -455,13 +435,12 @@ if ( Mirmon::verbose )
             my $que ;
             if ( $stat eq 'undef' ) # never probed ; new mirror ; todo
               { $col = 'new' ; $que = 'todo' ; }
-            elsif ( $conf -> get_xtr ( $mirror -> region ) )
-              { $col = 'xtr' ; $que = 'todo' ; }
             else
               { my $poll = $stat eq 'ok' ? $maxp : $minp ;
                 $col     = $stat eq 'ok' ? 'grn' : 'red' ;
                 $que     = ( aprx_le $lprb, $poll ) ? 'todo' : 'done' ;
               }
+
             push @{ $ques -> { $col } { $que } }, $mirror ;
           }
 
@@ -476,12 +455,11 @@ if ( Mirmon::verbose )
           ( @{ $ques -> { new } { todo } }
           , @{ $ques -> { red } { todo } }
           , @{ $ques -> { grn } { todo } }
-          , @{ $ques -> { xtr } { todo } }
           ) ;
       }
     else
       { die "unknown opt_get '$get'" ; }
-
+    
     if ( Mirmon::verbose ) { printf "queued %d\n\n", scalar @QUE ; }
 
     while ( @QUE )
@@ -978,7 +956,7 @@ sub gen_histogram
       { $res .= sprintf "<BR>each %s unit represents %s mirror sites.\n"
           , $units, sprintf ( "%.1f", $max / $H ) ;
       }
-    return H2 ( NAM 'age-histogram', 'age histogram' )
+    return H2 ( NAM 'age-histogram', 'age histogram' ) 
       . BQ $res ;
   }
 
@@ -1128,11 +1106,10 @@ $histo_top
 HEAD
 
     for my $reg
-      ( sort { _cmp_ccs $CCS, $a, $b } keys %tab )
-#      { ( $CCS -> { $a } ? lc ( $CCS -> { $a } ) : $a )
-#    cmp ( $CCS -> { $b } ? lc ( $CCS -> { $b } ) : $b )
-#      } keys %tab
-#     )
+      ( sort
+       { ( lc $CCS -> { $a } || $a ) cmp ( lc $CCS -> { $b } || $b ) ; }
+       keys %tab
+      )
       { my $mirrors = $tab { $reg } ;
 
         my $ccs = exists $CCS -> { $reg } ? $CCS -> { $reg } : $reg ;
@@ -1227,7 +1204,6 @@ our %CNF_defaults =
   , htm_top      => ''
   , htm_foot     => ''
   , htm_head     => ''
-  , always_get   => ''
   ) ;
 
 our @REQ_KEYS =
@@ -1242,12 +1218,6 @@ my @PUT_HGRAM  = qw(top bottom nowhere) ;
 
 eval Base -> mk_methods ( keys %CNF_KEYS, qw(root site_url) ) ;
 
-sub get_xtr
-  { my $self = shift ;
-    my $reg  = shift ;
-    scalar grep { $_ eq $reg } split ' ', $self -> always_get ;
-  }
-
 sub new
   { my $self = shift ;
     my $FILE = shift ;
@@ -1674,10 +1644,9 @@ Returns a hashref C<< { country_code =E<gt> country_name, ... } >>.
 
 Returns the list of default locations for config files.
 
-=item B<get_dates ( $get [, $URL] )>
+=item B<get_dates ( $get )>
 
-Probes all mirrors if $get is C<all> ; or a subset if $get is C<update> ;
-or only I<$URL> if $get is C<url>.
+Probes all mirrors if $get is C<all> ; or a subset if $get is C<update>.
 
 =back
 
@@ -1725,7 +1694,7 @@ The url as given in the mirror list.
 
 =item B<age>
 
-The mirror's timestamp found by the last successful probe,
+The mirror's timestamp found by the last succesful probe,
 or 'undef' if no probe was ever successful.
 
 =item B<last_status>
@@ -1734,7 +1703,7 @@ The status of the last probe, or 'undef' if the mirror was never probed.
 
 =item B<last_ok_probe>
 
-The timestamp of the last successful probe or 'undef'
+The timestamp of the last succesful probe or 'undef'
 if the mirror was never successfully probed.
 
 =item B<probe_history>
@@ -1822,9 +1791,7 @@ and updates the state of the mirror.
 
 =begin html
 
-<p>
-<a href="mirmon.html">mirmon(1)</a>
-</p>
+<A HREF="mirmon.html">mirmon(1)</A>
 
 =end html
 
@@ -1838,33 +1805,30 @@ mirmon(1)
 
 =begin html
 
-  <p>
-  &copy; 2003-2014
-  <a href="http://www.staff.science.uu.nl/~penni101/">Henk P. Penning</a>,
-  <a href="http://www.uu.nl/faculty/science/EN/">Faculty of Science</a>,
-  <a href="http://www.uu.nl/">Utrecht University</a>
-  <br />
-  mirmon-2.10 - Fri Aug 15 12:26:55 2014 ; henkp ;
-  <a href="http://validator.w3.org/check?uri=referer">verify html</a>
-  </p>
+  &copy; 2003-2012
+  <A HREF="http://people.cs.uu.nl/henkp/">Henk P. Penning</A>,
+  <A HREF="http://www.cs.uu.nl/">Computer Science Department</A>,
+  <A HREF="http://www.uu.nl/">Utrecht University</A>
+  <BR>
+  mirmon-2.5 - Sat Mar 24 09:07:39 2012 ; henkp
 
 =end html
 
 =begin man
 
-  (c) 2003-2014 Henk P. Penning
-  Faculty of Science, Utrecht University
-  http://www.staff.science.uu.nl/~penni101/ -- penning@uu.nl
-  mirmon-2.10 - Fri Aug 15 12:26:55 2014 ; henkp
+  (c) 2003-2012 Henk P. Penning
+  Computer Science Department, Utrecht University
+  http://people.cs.uu.nl/henkp/ -- penning@cs.uu.nl
+  mirmon-2.5 - Sat Mar 24 09:07:39 2012 ; henkp
 
 =end man
 
 =begin text
 
-  (c) 2003-2014 Henk P. Penning
-  Faculty of Science, Utrecht University
-  http://www.staff.science.uu.nl/~penni101/ -- penning@uu.nl
-  mirmon-2.10 - Fri Aug 15 12:26:55 2014 ; henkp
+  (c) 2003-2012 Henk P. Penning
+  Computer Science Department, Utrecht University
+  http://people.cs.uu.nl/henkp/ -- penning@cs.uu.nl
+  mirmon-2.5 - Sat Mar 24 09:07:39 2012 ; henkp
 
 =end text
 
